@@ -160,8 +160,6 @@ class solver():
                     ##  这里就表示如果要算某些反应的flux值(比如时间导数那里有这个反应的话)，就必须加入到sub_objectives中. 不过也可以优化，只不过到时候要在solution里面去找对应的
                     var[model_name + '_M_' + sub_objectives[i].id] = flux_values.at[
                         sub_objectives[i].id, sub_objective_directions[i]]
-                    # print(model_name + '_' +sub_objectives[i].id)
-                    # print(var[model_name + '_' +sub_objectives[i].id])
                     ##  加入一个环节  由于设定了几个次级目的反应的flux值，必将影响主要优化目标的flux值，所以把计算得到的次级目的反应flux值给赋值回去再计算objective
                     ##  好像没啥用，反正都是在这个线性空间里面去求解objective的最大最小值，除非把上下限设置得紧密一些
                     # sub_objectives[i].upper_bound = 1000
@@ -192,9 +190,8 @@ class solver():
                 model_mu = model_name + '_mu'  # 优化后的生长率flux值变量名
                 if model_mu in rxnsFluxValue_keys:  # 计算了这个菌的生长率, derivatives就不为0
                     dilution_rate = self.models_dict[model_name].dilrate
-                    derivative['d'] = self.states[state_name] * var[model_mu] - self.states_var[
+                    derivative['d'] = self.states_var[state_name] * var[model_mu] - self.states_var[
                         state_name] * dilution_rate
-                    # print("导数: %f" % derivative['d'])
             elif self.derivatives_description[state_name] == '0':
                 pass
             elif state_name in derivatives_keys:  # 要求计算这种物质时间导数  3.28 添加功能，也可以识别没有修改过的反应->完成
@@ -216,9 +213,8 @@ class solver():
                         else:
                             flux = var[model_name + '_solution'].fluxes[flux_name]
                             exec('var[item] =' + model_weight + '* flux')
-                            # print('%s=%f' % (item, var[item]))
                 exec("derivative['d']=" + derivative_description)
-                # print("%s导数: %f" % (state_name, derivative['d']))
+            # print("%s导数: %f" % (state_name, derivative['d']))
             derivatives.append(derivative['d'])
 
         return np.array(derivatives)
